@@ -9,6 +9,7 @@
 #' }
 #'                 
 #' @param doi a Zenodo DOI or concept DOI
+#' @param sandbox Use the sandbox infrastructure. Default is \code{FALSE}
 #' @param logger a logger to print messages. The logger can be either NULL, 
 #' "INFO" (with minimum logs), or "DEBUG" (for complete curl http calls logs)
 #' @return an object of class \code{data.frame} giving the record versions
@@ -16,9 +17,9 @@
 #' 
 #' @export
 #' 
-get_versions = function(doi, logger = NULL){
+get_versions = function(doi, sandbox = FALSE, logger = NULL){
   #get
-  rec = get_zenodo(doi = doi, logger = logger)
+  rec = get_zenodo(doi = doi, sandbox = sandbox, logger = logger)
   #versions
   versions <- rec$getVersions()
   return(versions)
